@@ -4,5 +4,5 @@ from .create_action_item import SingletonActionItemError, create_action_item
 from .decorators import register
 from .delete_action_item import ActionItemDeleteError, delete_action_item
 from .fieldsets import action_fields, action_fieldset_tuple
-from .modeladmin_mixins import ModelAdminActionItemMixin
+from .modeladmin_mixins import ActionItemModelAdminMixin
 from .site_action_items import site_action_items
